@@ -49,8 +49,6 @@ See L<Rex::Commands> for a list of all commands you can use.
 
 =head1 CLASS METHODS
 
-=over 4
-
 =cut
 
 package Rex;
@@ -58,7 +56,7 @@ package Rex;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 # development version if this variable is not set
 if ( !$Rex::VERSION ) {
@@ -228,7 +226,7 @@ sub modified_caller {
   }
 }
 
-=item get_current_connection
+=head2 get_current_connection
 
 This function is deprecated since 0.28! See Rex::Commands::connection.
 
@@ -272,7 +270,7 @@ sub get_current_connection_object {
   return Rex::get_current_connection()->{conn};
 }
 
-=item is_ssh
+=head2 is_ssh
 
 Returns 1 if the current connection is a ssh connection. 0 if not.
 
@@ -289,7 +287,7 @@ sub is_ssh {
   return 0;
 }
 
-=item is_local
+=head2 is_local
 
 Returns 1 if the current connection is local. Otherwise 0.
 
@@ -306,7 +304,7 @@ sub is_local {
   return 0;
 }
 
-=item is_sudo
+=head2 is_sudo
 
 Returns 1 if the current operation is executed within sudo.
 
@@ -336,7 +334,7 @@ sub global_sudo {
   Rex::Config->set_use_cache(1);
 }
 
-=item get_sftp
+=head2 get_sftp
 
 Returns the sftp object for the current ssh connection.
 
@@ -358,7 +356,7 @@ sub get_cache {
   return Rex::Interface::Cache->create();
 }
 
-=item connect
+=head2 connect
 
 Use this function to create a connection if you use Rex as a library.
 
@@ -542,6 +540,8 @@ sub import {
 
       if ( $add =~ m/^(\d+\.\d+)$/ ) {
         my $_ver = $Rex::VERSION;
+        $_ver =~ s/_\d+$//; # remove rc info
+
         my $vers = $1;
         my ( $major, $minor, $patch ) = split( /\./, $_ver );
         my ( $c_major, $c_minor ) = split( /\./, $vers );
@@ -557,6 +557,12 @@ sub import {
         }
       }
 
+      if ( $add =~ m/^\d+\.\d+$/ && $add >= 1.3 ) {
+        Rex::Logger::debug("Activating new template engine.");
+        Rex::Config->set_use_template_ng(1);
+        $found_feature = 1;
+      }
+
       if ( $add =~ m/^\d+\.\d+$/ && $add >= 1.0 ) {
         Rex::Logger::debug("Disabling usage of a tty");
         Rex::Config->set_no_tty(1);
@@ -652,11 +658,17 @@ sub import {
       }
 
       if ( $add eq "template_ng" ) {
-        Rex::Logger::debug("Activating experimental new template engine.");
+        Rex::Logger::debug("Activating new template engine.");
         Rex::Config->set_use_template_ng(1);
         $found_feature = 1;
       }
 
+      if ( $add eq "no_template_ng" ) {
+        Rex::Logger::debug("Deactivating new template engine.");
+        Rex::Config->set_use_template_ng(0);
+        $found_feature = 1;
+      }
+
       if ( $add eq "register_cmdb_top_scope" ) {
         Rex::Logger::debug("Registering CMDB as template variables.");
         Rex::Config->set_register_cmdb_template(1);
@@ -799,8 +811,6 @@ sub import {
   strict->import;
 }
 
-=back
-
 =head1 CONTRIBUTORS
 
 Many thanks to the contributors for their work. Please see L<CONTRIBUTORS|https://github.com/RexOps/Rex/blob/master/CONTRIBUTORS> file for a complete list.
