@@ -9,7 +9,7 @@ package Rex::CLI;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use FindBin;
 use File::Basename;
@@ -94,8 +94,7 @@ sub __run__ {
     G => { type => "string" },
     g => { type => "string" },
     z => { type => "string" },
-    O => { type => "string" },
-    t => { type => "integer" },
+    t => { type => "string" },
     %more_args,
   );
 
@@ -308,6 +307,7 @@ FORCE_SERVER: {
         }
         push @rex_code, "my \$b=\$Rex::Commands::dont_register_tasks;";
         push @rex_code, "\$Rex::Commands::dont_register_tasks = 1;";
+        push @rex_code, "our \$syntax_check = 1;";
         push @rex_code, "$content";
         push @rex_code, "\$Rex::Commands::dont_register_tasks = \$b;";
         push @rex_code, "1;";
@@ -647,41 +647,47 @@ sub _print_color {
 
 sub __help__ {
 
-  print "(R)?ex - (Remote)? Execution\n";
-  printf "  %-15s %s\n", "-b", "Run batch";
-  printf "  %-15s %s\n", "-e", "Run the given code fragment";
-  printf "  %-15s %s\n", "-E", "Execute task on the given environment";
-  printf "  %-15s %s\n", "-H", "Execute task on these hosts";
-  printf "  %-15s %s\n", "-z",
-    "Execute task on hosts from this command's output";
-  printf "  %-15s %s\n", "-G|-g", "Execute task on these group";
-  printf "  %-15s %s\n", "-u",    "Username for the ssh connection";
-  printf "  %-15s %s\n", "-p",    "Password for the ssh connection";
-  printf "  %-15s %s\n", "-P",    "Private Keyfile for the ssh connection";
-  printf "  %-15s %s\n", "-K",    "Public Keyfile for the ssh connection";
-  printf "  %-15s %s\n", "-T",    "List all known tasks.";
-  printf "  %-15s %s\n", "-Tm",
-    "List all known tasks, in machine-readable format.";
-  printf "  %-15s %s\n", "-Ty", "List all known tasks, in YAML format.";
-  printf "  %-15s %s\n", "-Tv", "List all known tasks with all information.";
-  printf "  %-15s %s\n", "-f",  "Use this file instead of Rexfile";
-  printf "  %-15s %s\n", "-h",  "Display this help";
-  printf "  %-15s %s\n", "-m",  "Monochrome output. No colors";
-  printf "  %-15s %s\n", "-M",  "Load Module instead of Rexfile";
-  printf "  %-15s %s\n", "-v",  "Display (R)?ex Version";
-  printf "  %-15s %s\n", "-F",  "Force. Don't regard lock file";
-  printf "  %-15s %s\n", "-s",  "Use sudo for every command";
-  printf "  %-15s %s\n", "-S",  "Password for sudo";
-  printf "  %-15s %s\n", "-d",  "Debug";
-  printf "  %-15s %s\n", "-dd", "More Debug (includes Profiling Output)";
-  printf "  %-15s %s\n", "-o",  "Output Format";
-  printf "  %-15s %s\n", "-c",  "Turn cache ON";
-  printf "  %-15s %s\n", "-C",  "Turn cache OFF";
-  printf "  %-15s %s\n", "-q",  "Quiet mode. No Logging output";
-  printf "  %-15s %s\n", "-qw", "Quiet mode. Only output warnings and errors";
-  printf "  %-15s %s\n", "-Q",  "Really quiet. Output nothing.";
-  printf "  %-15s %s\n", "-t",
-    "Number of threads to use (aka 'parallelism' param)";
+  my $fmt = "  %-6s %s\n";
+
+  print "usage: \n";
+  print "  rex [<options>] [-H <host>] [-G <group>] <task> [<task-options>]\n";
+  print "  rex -T[m|y|v] [<string>]\n";
+  print "\n";
+  printf $fmt, "-b",    "Run batch";
+  printf $fmt, "-e",    "Run the given code fragment";
+  printf $fmt, "-E",    "Execute a task on the given environment";
+  printf $fmt, "-G|-g", "Execute a task on the given server groups";
+  printf $fmt, "-H",    "Execute a task on the given hosts (space delimited)";
+  printf $fmt, "-z",    "Execute a task on hosts from this command's output";
+  print "\n";
+  printf $fmt, "-K", "Public key file for the ssh connection";
+  printf $fmt, "-P", "Private key file for the ssh connection";
+  printf $fmt, "-p", "Password for the ssh connection";
+  printf $fmt, "-u", "Username for the ssh connection";
+  print "\n";
+  printf $fmt, "-d",   "Show debug output";
+  printf $fmt, "-ddd", "Show more debug output (includes profiling output)";
+  printf $fmt, "-m",   "Monochrome output: no colors";
+  printf $fmt, "-o",   "Output format";
+  printf $fmt, "-q",   "Quiet mode: no log output";
+  printf $fmt, "-qw",  "Quiet mode: only output warnings and errors";
+  printf $fmt, "-Q",   "Really quiet: output nothing";
+  print "\n";
+  printf $fmt, "-T",  "List tasks";
+  printf $fmt, "-Tm", "List tasks in machine-readable format";
+  printf $fmt, "-Tv", "List tasks verbosely";
+  printf $fmt, "-Ty", "List tasks in YAML format";
+  print "\n";
+  printf $fmt, "-c", "Turn cache ON";
+  printf $fmt, "-C", "Turn cache OFF";
+  printf $fmt, "-f", "Use this file instead of Rexfile";
+  printf $fmt, "-F", "Force: disregard lock file";
+  printf $fmt, "-h", "Display this help message";
+  printf $fmt, "-M", "Load this module instead of Rexfile";
+  printf $fmt, "-s", "Use sudo for every command";
+  printf $fmt, "-S", "Password for sudo";
+  printf $fmt, "-t", "Number of threads to use (aka 'parallelism' param)";
+  printf $fmt, "-v", "Display (R)?ex version";
   print "\n";
 
   for my $code (@help) {
@@ -723,11 +729,13 @@ sub _list_tasks {
   Rex::Logger::debug("Listing Tasks");
 
   my @tasks = Rex::TaskList->create()->get_tasks;
-  @tasks = grep { $_ =~ /^$ARGV[0]/ } @tasks if defined $ARGV[0];
+  if ( defined $ARGV[0] ) {
+    @tasks = grep { $_ =~ /^$ARGV[0]/ } @tasks;
 
-  # Warn if the user passed args to '-T' and no matching task names were found
-  Rex::Logger::info( "No tasks matching '$ARGV[0]' found.", "error" )
-    unless @tasks;
+    # Warn if the user passed args to '-T' and no matching task names were found
+    Rex::Logger::info( "No tasks matching '$ARGV[0]' found.", "error" )
+      unless @tasks;
+  }
 
   return unless @tasks;
 
