@@ -9,7 +9,7 @@ package Rex::CMDB::YAML;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use base qw(Rex::CMDB::Base);
 
@@ -85,7 +85,7 @@ sub get {
     );
   }
   elsif ( ref $self->{path} eq "CODE" ) {
-    @files = $self->{path}->();
+    @files = $self->{path}->( $self, $item, $server );
   }
   elsif ( ref $self->{path} eq "ARRAY" ) {
     @files = @{ $self->{path} };
