@@ -21,8 +21,6 @@ All these functions will not be reported. These functions don't modify anything.
 
 =head1 EXPORTED FUNCTIONS
 
-=over 4
-
 =cut
 
 package Rex::Commands::Gather;
@@ -30,7 +28,7 @@ package Rex::Commands::Gather;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Data::Dumper;
 use Rex::Hardware;
@@ -50,7 +48,7 @@ use vars qw(@EXPORT);
   is_freebsd is_netbsd is_openbsd is_redhat is_linux is_bsd is_solaris is_suse is_debian is_mageia is_windows is_alt is_openwrt is_gentoo is_fedora
   get_system_information dump_system_information);
 
-=item get_operating_system
+=head2 get_operating_system
 
 Will return the current operating system name.
 
@@ -72,7 +70,7 @@ sub operating_system {
   return get_operating_system();
 }
 
-=item get_system_information
+=head2 get_system_information
 
 Will return a hash of all system information. These Information will be also used by the template function.
 
@@ -82,7 +80,7 @@ sub get_system_information {
   return Rex::Helper::System::info();
 }
 
-=item dump_system_information
+=head2 dump_system_information
 
 This function dumps all known system information on stdout.
 
@@ -96,7 +94,7 @@ sub dump_system_information {
     { prepend_key => '$', key_value_sep => " = ", no_root => 1 } );
 }
 
-=item operating_system_is($string)
+=head2 operating_system_is($string)
 
 Will return 1 if the operating system is $string.
 
@@ -122,7 +120,7 @@ sub operating_system_is {
 
 }
 
-=item operating_system_version()
+=head2 operating_system_version()
 
 Will return the os release number as an integer. For example, it will convert 5.10 to 510, 10.04 to 1004 or 6.0.3 to 603.
 
@@ -146,7 +144,7 @@ sub operating_system_version {
 
 }
 
-=item operating_system_release()
+=head2 operating_system_release()
 
 Will return the os release number as is.
 
@@ -157,7 +155,7 @@ sub operating_system_release {
   return Rex::Hardware::Host->get_operating_system_version();
 }
 
-=item network_interfaces
+=head2 network_interfaces
 
 Return an HashRef of all the networkinterfaces and their configuration.
 
@@ -182,7 +180,7 @@ sub network_interfaces {
 
 }
 
-=item memory
+=head2 memory
 
 Return an HashRef of all memory information.
 
@@ -206,7 +204,7 @@ sub memory {
 
 }
 
-=item is_freebsd
+=head2 is_freebsd
 
 Returns true if the target system is a FreeBSD.
 
@@ -228,7 +226,7 @@ sub is_freebsd {
   }
 }
 
-=item is_redhat
+=head2 is_redhat
 
  task "foo", "server1", sub {
    if(is_redhat) {
@@ -246,7 +244,8 @@ sub is_redhat {
     "CentOS",                      "Scientific",
     "RedHatEnterpriseServer",      "RedHatEnterpriseES",
     "RedHatEnterpriseWorkstation", "RedHatEnterpriseWS",
-    "Amazon",                      "ROSAEnterpriseServer"
+    "Amazon",                      "ROSAEnterpriseServer",
+    "CloudLinuxServer",
   );
 
   if ( grep { /$os/i } @redhat_clones ) {
@@ -254,7 +253,7 @@ sub is_redhat {
   }
 }
 
-=item is_fedora
+=head2 is_fedora
 
  task "foo", "server1", sub {
    if(is_fedora) {
@@ -274,7 +273,7 @@ sub is_fedora {
   }
 }
 
-=item is_suse
+=head2 is_suse
 
  task "foo", "server1", sub {
    if(is_suse) {
@@ -294,7 +293,7 @@ sub is_suse {
   }
 }
 
-=item is_mageia
+=head2 is_mageia
 
  task "foo", "server1", sub {
    if(is_mageia) {
@@ -314,7 +313,7 @@ sub is_mageia {
   }
 }
 
-=item is_debian
+=head2 is_debian
 
  task "foo", "server1", sub {
    if(is_debian) {
@@ -334,7 +333,7 @@ sub is_debian {
   }
 }
 
-=item is_alt
+=head2 is_alt
 
  task "foo", "server1", sub {
    if(is_alt) {
@@ -354,7 +353,7 @@ sub is_alt {
   }
 }
 
-=item is_netbsd
+=head2 is_netbsd
 
 Returns true if the target system is a NetBSD.
 
@@ -376,7 +375,7 @@ sub is_netbsd {
   }
 }
 
-=item is_openbsd
+=head2 is_openbsd
 
 Returns true if the target system is an OpenBSD.
 
@@ -398,7 +397,7 @@ sub is_openbsd {
   }
 }
 
-=item is_linux
+=head2 is_linux
 
 Returns true if the target system is a Linux System.
 
@@ -424,7 +423,7 @@ sub is_linux {
   }
 }
 
-=item is_bsd
+=head2 is_bsd
 
 Returns true if the target system is a BSD System.
 
@@ -447,7 +446,7 @@ sub is_bsd {
   }
 }
 
-=item is_solaris
+=head2 is_solaris
 
 Returns true if the target system is a Solaris System.
 
@@ -473,7 +472,7 @@ sub is_solaris {
   }
 }
 
-=item is_windows
+=head2 is_windows
 
 Returns true if the target system is a Windows System.
 
@@ -490,7 +489,7 @@ sub is_windows {
 
 }
 
-=item is_openwrt
+=head2 is_openwrt
 
 Returns true if the target system is an OpenWrt System.
 
@@ -504,7 +503,7 @@ sub is_openwrt {
 
 }
 
-=item is_gentoo
+=head2 is_gentoo
 
 Returns true if the target system is a Gentoo System.
 
@@ -518,8 +517,4 @@ sub is_gentoo {
 
 }
 
-=back
-
-=cut
-
 1;
