@@ -20,8 +20,6 @@ With this module you can run a command.
 
 =head1 EXPORTED FUNCTIONS
 
-=over 4
-
 =cut
 
 package Rex::Commands::Run;
@@ -29,7 +27,7 @@ package Rex::Commands::Run;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 #require Exporter;
 require Rex::Exporter;
@@ -59,9 +57,9 @@ use base qw(Rex::Exporter);
 
 @EXPORT = qw(run can_run sudo);
 
-=item run($command [, $callback])
+=head2 run($command [, $callback])
 
-=item run($command_description, command => $command, %options)
+=head2 run($command_description, command => $command, %options)
 
 This function will execute the given command and returns the output. In
 scalar context it returns the raw output as is, and in list context it
@@ -226,6 +224,7 @@ sub run {
   }
 
   my $out_ret;
+  my ( $out, $err );
 
   if ($changed) {
     my $path;
@@ -234,7 +233,6 @@ sub run {
       $path = join( ":", Rex::Config->get_path() );
     }
 
-    my ( $out, $err );
     my $exec = Rex::Interface::Exec->create;
     if ( exists $option->{timeout} && $option->{timeout} > 0 ) {
       eval {
@@ -301,7 +299,7 @@ sub run {
 
   if ( exists $option->{auto_die} && $option->{auto_die} ) {
     if ( $? != 0 ) {
-      die("Error executing: $cmd.\nOutput:\n$out_ret");
+      die("Error executing: $cmd.\nSTDOUT:\n$out\nSTDERR:\n$err");
     }
   }
 
@@ -312,7 +310,7 @@ sub run {
   return $out_ret;
 }
 
-=item can_run($command)
+=head2 can_run($command)
 
 This function checks if a command is in the path or is available. You can
 specify multiple commands, the first command found will be returned.
@@ -331,7 +329,7 @@ sub can_run {
   $exec->can_run( [@commands] ); # use a new anon ref, so that we don't have drawbacks if some lower layers will manipulate things.
 }
 
-=item sudo
+=head2 sudo
 
 Run a command with I<sudo>. Define the password for sudo with I<sudo_password>.
 
@@ -410,8 +408,4 @@ sub sudo {
   return $ret;
 }
 
-=back
-
-=cut
-
 1;
