@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use POSIX ":sys_wait_h";
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 BEGIN {
 
@@ -41,7 +41,7 @@ sub start {
 
     # only allow this if no parallelism is given.
     # with parallelism active it doesn't make sense.
-    if ( $Rex::WITH_EXIT_STATUS && Rex::Config->get_parallelism == 1 ) {
+    if ($Rex::WITH_EXIT_STATUS) {
       eval {
         &$func($self);
         1;
