@@ -9,7 +9,7 @@ package Rex::Group;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Logger;
 
@@ -73,7 +73,7 @@ sub create_group {
     next if ref $server[$i] eq 'HASH'; # already processed by previous loop
 
     # if argument is already a Rex::Group::Entry::Server
-    if ( ref( $server[$i] ) eq "Rex::Group::Entry::Server" ) {
+    if ( ref $server[$i] && $server[$i]->isa("Rex::Group::Entry::Server") ) {
       push @server_obj, $server[$i];
       next;
     }
