@@ -9,7 +9,7 @@ package Rex::Group::Entry::Server;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::System;
@@ -100,11 +100,11 @@ sub new {
 sub get_servers {
   my ($self) = @_;
   return uniq map {
-    if ( ref($_) ne "Rex::Group::Entry::Server" ) {
-      $_ = Rex::Group::Entry::Server->new( name => $_, auth => $self->{auth} );
+    if ( ref $_ && $_->isa("Rex::Group::Entry::Server") ) {
+      $_;
     }
     else {
-      $_;
+      $_ = Rex::Group::Entry::Server->new( name => $_, auth => $self->{auth} );
     }
   } $self->evaluate_hostname;
 }
