@@ -9,7 +9,7 @@ package Rex::Interface::Connection::Base;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Interface::Fs;
 use Rex::Interface::Exec;
@@ -95,6 +95,10 @@ sub push_use_sudo {
 
 sub get_current_use_sudo {
   my ($self) = @_;
+
+  if ( $self->{is_sudo} ) {
+    return 1;
+  }
   return $self->{__use_sudo__}->[-1];
 }
 
