@@ -9,7 +9,7 @@ package Rex::Interface::Exec::Local;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Logger;
 use Rex::Commands;
@@ -61,7 +61,7 @@ sub exec {
   }
 
   if ( exists $option->{format_cmd} ) {
-    $option->{format_cmd} =~ s/{{CMD}}/$cmd/;
+    $option->{format_cmd} =~ s/\{\{CMD\}\}/$cmd/;
     $cmd = $option->{format_cmd};
   }
 
