@@ -9,7 +9,7 @@ package Rex::Interface::Exec::Sudo;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Config;
 use Rex::Interface::Exec::Local;
@@ -139,7 +139,7 @@ EOF
 
     # $option->{format_cmd} =
     #   "perl $random_file '$enc_pw' | sudo $sudo_options_str -p '' -S {{CMD}}";
-      $sudo_command = "perl $random_file '$enc_pw' | $sudo_command";
+      $sudo_command = "perl $random_file '$enc_pw' 2>/dev/null | $sudo_command";
     }
 
     # else {
@@ -181,7 +181,7 @@ EOF
 # $option->{_force_sh} = 1;
 
     if ($enc_pw) {
-      $sudo_command = "perl $random_file '$enc_pw' | $sudo_command";
+      $sudo_command = "perl $random_file '$enc_pw' 2>/dev/null | $sudo_command";
 
 # $option->{format_cmd} =
 #   "perl $random_file '$enc_pw' | sudo $sudo_options_str -p '' -S sh -c \"{{CMD}}\"";
