@@ -9,7 +9,7 @@ package Rex::Interface::Shell::Bash;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Interface::Shell::Base;
 use base qw(Rex::Interface::Shell::Base);
@@ -123,7 +123,7 @@ sub exec {
 
   # rewrite the command again
   if ( exists $option->{format_cmd} ) {
-    $complete_cmd =~ s/{{CMD}}/$cmd/;
+    $complete_cmd =~ s/\{\{CMD\}\}/$cmd/;
   }
 
   if ( $self->{__inner_shell__} ) {
