@@ -9,7 +9,7 @@ package Rex::Service;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Config;
 use Rex::Commands::Run;
@@ -53,6 +53,11 @@ sub get {
   elsif ( is_mageia($operatingsystem) && $can_run_systemctl ) {
     $class = "Rex::Service::Mageia::systemd";
   }
+  elsif ( is_debian($operatingsystem) && $can_run_systemctl ) {
+
+    # this also counts for Ubuntu
+    $class = "Rex::Service::Debian::systemd";
+  }
 
   my $provider_for = Rex::Config->get("service_provider") || {};
   my $provider;
