@@ -23,8 +23,6 @@ The Task Object. Typically you only need this class if you want to manipulate ta
 
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Rex::Task;
@@ -34,7 +32,7 @@ use warnings;
 use Data::Dumper;
 use Time::HiRes qw(time);
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Logger;
 use Rex::TaskList;
@@ -54,7 +52,7 @@ require Rex::Commands;
 
 require Rex::Args;
 
-=item new
+=head2 new
 
 This is the constructor.
 
@@ -107,7 +105,7 @@ sub new {
   return $self;
 }
 
-=item connection
+=head2 connection
 
 Returns the current connection object.
 
@@ -123,7 +121,7 @@ sub connection {
   $self->{connection};
 }
 
-=item executor
+=head2 executor
 
 Returns the current executor object.
 
@@ -135,7 +133,7 @@ sub executor {
   return $self->{executor};
 }
 
-=item hidden
+=head2 hidden
 
 Returns true if the task is hidden. (Should not be displayed on ,,rex -T''.)
 
@@ -146,7 +144,7 @@ sub hidden {
   return $self->{hidden};
 }
 
-=item server
+=head2 server
 
 Returns the servers on which the task should be executed as an ArrayRef.
 
@@ -183,7 +181,7 @@ sub server {
         push( @ret, &$srv() );
       }
       else {
-        if ( ref($srv) eq "Rex::Group::Entry::Server" ) {
+        if ( ref $srv && $srv->isa("Rex::Group::Entry::Server") ) {
           push( @ret, $srv->get_servers );
         }
         else {
@@ -202,7 +200,7 @@ sub server {
   return [@ret];
 }
 
-=item set_server(@server)
+=head2 set_server(@server)
 
 With this method you can set new servers on which the task should be executed on.
 
@@ -213,7 +211,7 @@ sub set_server {
   $self->{server} = \@server;
 }
 
-=item delete_server
+=head2 delete_server
 
 Delete every server registered to the task.
 
@@ -226,7 +224,7 @@ sub delete_server {
   $self->rethink_connection;
 }
 
-=item current_server
+=head2 current_server
 
 Returns the current server on which the tasks gets executed right now.
 
@@ -238,7 +236,7 @@ sub current_server {
     || Rex::Group::Entry::Server->new( name => "<local>" );
 }
 
-=item desc
+=head2 desc
 
 Returns the description of a task.
 
@@ -249,7 +247,7 @@ sub desc {
   return $self->{desc};
 }
 
-=item set_desc($description)
+=head2 set_desc($description)
 
 Set the description of a task.
 
@@ -260,7 +258,7 @@ sub set_desc {
   $self->{desc} = $desc;
 }
 
-=item is_remote
+=head2 is_remote
 
 Returns true (1) if the task will be executed remotely.
 
@@ -282,7 +280,7 @@ sub is_remote {
   return 0;
 }
 
-=item is_local
+=head2 is_local
 
 Returns true (1) if the task gets executed on the local host.
 
@@ -293,7 +291,7 @@ sub is_local {
   return $self->is_remote() == 0 ? 1 : 0;
 }
 
-=item is_http
+=head2 is_http
 
 Returns true (1) if the task gets executed over http protocol.
 
@@ -317,7 +315,7 @@ sub is_openssh {
       && lc( $self->{"connection_type"} ) eq "openssh" );
 }
 
-=item want_connect
+=head2 want_connect
 
 Returns true (1) if the task will establish a connection to a remote system.
 
@@ -328,7 +326,7 @@ sub want_connect {
   return $self->{no_ssh} == 0 ? 1 : 0;
 }
 
-=item get_connection_type
+=head2 get_connection_type
 
 This method tries to guess the right connection type for the task and returns it.
 
@@ -365,7 +363,7 @@ sub get_connection_type {
   }
 }
 
-=item modify($key, $value)
+=head2 modify($key, $value)
 
 With this method you can modify values of the task.
 
@@ -390,7 +388,7 @@ sub rethink_connection {
   $self->connection;
 }
 
-=item user
+=head2 user
 
 Returns the current user the task will use.
 
@@ -403,7 +401,7 @@ sub user {
   }
 }
 
-=item set_user($user)
+=head2 set_user($user)
 
 Set the user of a task.
 
@@ -414,7 +412,7 @@ sub set_user {
   $self->{auth}->{user} = $user;
 }
 
-=item password
+=head2 password
 
 Returns the password that will be used.
 
@@ -427,7 +425,7 @@ sub password {
   }
 }
 
-=item set_password($password)
+=head2 set_password($password)
 
 Set the password of the task.
 
@@ -438,7 +436,7 @@ sub set_password {
   $self->{auth}->{password} = $password;
 }
 
-=item name
+=head2 name
 
 Returns the name of the task.
 
@@ -449,7 +447,7 @@ sub name {
   return $self->{name};
 }
 
-=item code
+=head2 code
 
 Returns the code of the task.
 
@@ -460,7 +458,7 @@ sub code {
   return $self->{func};
 }
 
-=item set_code(\&code_ref)
+=head2 set_code(\&code_ref)
 
 Set the code of the task.
 
@@ -471,7 +469,7 @@ sub set_code {
   $self->{func} = $code;
 }
 
-=item run_hook($server, $hook)
+=head2 run_hook($server, $hook)
 
 This method is used internally to execute the specified hooks.
 
@@ -498,7 +496,7 @@ sub run_hook {
   }
 }
 
-=item set_auth($key, $value)
+=head2 set_auth($key, $value)
 
 Set the authentication of the task.
 
@@ -519,7 +517,7 @@ sub set_auth {
   }
 }
 
-=item merge_auth($server)
+=head2 merge_auth($server)
 
 Merges the authentication information from $server into the task.
 Tasks authentication information have precedence.
@@ -545,7 +543,7 @@ sub get_sudo_password {
   return $auth{sudo_password};
 }
 
-=item parallelism
+=head2 parallelism
 
 Get the parallelism count of a task.
 
@@ -556,7 +554,7 @@ sub parallelism {
   return $self->{parallelism};
 }
 
-=item set_parallelism($count)
+=head2 set_parallelism($count)
 
 Set the parallelism of the task.
 
@@ -567,7 +565,7 @@ sub set_parallelism {
   $self->{parallelism} = $para;
 }
 
-=item connect($server)
+=head2 connect($server)
 
 Initiate the connection to $server.
 
@@ -576,7 +574,7 @@ Initiate the connection to $server.
 sub connect {
   my ( $self, $server, %override ) = @_;
 
-  if ( ref($server) ne "Rex::Group::Entry::Server" ) {
+  if ( !ref $server ) {
     $server = Rex::Group::Entry::Server->new( name => $server );
   }
   $self->{current_server} = $server;
@@ -676,7 +674,7 @@ sub connect {
   return 1;
 }
 
-=item disconnect
+=head2 disconnect
 
 Disconnect from the current connection.
 
@@ -724,7 +722,7 @@ sub get_data {
 # for compatibility
 #####################################
 
-=item run($server, %options)
+=head2 run($server, %options)
 
 Run the task on $server.
 
@@ -736,7 +734,7 @@ sub run {
   if ( ref( $_[0] ) ) {
     my ( $self, $server, %options ) = @_;
 
-    if ( ref($server) ne "Rex::Group::Entry::Server" ) {
+    if ( !ref $server ) {
       $server = Rex::Group::Entry::Server->new( name => $server );
     }
 
@@ -858,7 +856,7 @@ sub get_desc {
   return Rex::TaskList->create()->get_desc(@tmp);
 }
 
-=item exit_on_connect_fail()
+=head2 exit_on_connect_fail()
 
 Returns true if rex should exit on connect failure.
 
@@ -874,8 +872,4 @@ sub set_exit_on_connect_fail {
   $self->{exit_on_connect_fail} = $exit;
 }
 
-=back
-
-=cut
-
 1;
