@@ -9,7 +9,7 @@ package Rex::TaskList::Base;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Data::Dumper;
 use Rex::Logger;
@@ -20,6 +20,7 @@ use Rex::Fork::Manager;
 use Rex::Report;
 use Rex::Group;
 use Time::HiRes qw(time);
+use POSIX qw(floor);
 
 sub new {
   my $that  = shift;
@@ -152,7 +153,12 @@ sub create_task {
               }
 
               return map {
-                Rex::Group::Entry::Server->new( name => $_ )->get_servers
+                if ( ref $_ && $_->isa("Rex::Group::Entry::Server") ) {
+                  $_->get_servers;
+                }
+                else {
+                  Rex::Group::Entry::Server->new( name => $_ )->get_servers;
+                }
               } Rex::Group->get_group($group);
             };
 
@@ -164,7 +170,7 @@ sub create_task {
           push(
             @server,
             (
-              ref($entry) eq "Rex::Group::Entry"
+              ref $entry && $entry->isa("Rex::Group::Entry::Server")
               ? $entry
               : Rex::Group::Entry::Server->new( name => $entry )
             )
@@ -278,8 +284,7 @@ sub run {
 
   my @all_server = @{ $task->server };
 
-  my $fm = Rex::Fork::Manager->new( max => $task->parallelism
-      || Rex::Config->get_parallelism );
+  my $fm = Rex::Fork::Manager->new( max => $self->get_thread_count($task) );
 
   for my $server (@all_server) {
 
@@ -329,7 +334,7 @@ sub run {
 sub modify {
   my ( $self, $type, $task, $code, $package, $file, $line ) = @_;
 
-  return if $Rex::Commands::dont_register_tasks;
+  return if defined $Rex::Test::Rexfile::Syntax::syntax_check;
 
   if ( $package ne "main" && $package ne "Rex::CLI" ) {
     if ( $task !~ m/:/ ) {
@@ -385,4 +390,21 @@ sub get_exit_codes {
   return @Rex::Fork::Task::PROCESS_LIST;
 }
 
+sub get_thread_count {
+  my ( $self, $task ) = @_;
+  my $threads = $task->parallelism || Rex::Config->get_parallelism;
+  my $server_count = scalar @{ $task->server };
+
+  return $1                                if $threads =~ /^(\d+)$/;
+  return floor( $server_count / $1 )       if $threads =~ /^max\s?\/(\d+)$/;
+  return floor( $server_count * $1 / 100 ) if $threads =~ /^max (\d+)%$/;
+  return $server_count                     if $threads eq 'max';
+
+  Rex::Logger::info(
+    "Unrecognized thread count requested: '$threads'. Falling back to a single thread.",
+    'warn'
+  );
+  return 1;
+}
+
 1;
