@@ -9,7 +9,7 @@ package Rex::TaskList::Parallel_ForkManager;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.0'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Data::Dumper;
 use Rex::Logger;
@@ -47,8 +47,7 @@ sub run {
 
   my @all_server = @{ $task->server };
 
-  my $fm = Parallel::ForkManager->new( $task->parallelism
-      || Rex::Config->get_parallelism );
+  my $fm = Rex::Fork::Manager->new( max => $self->get_thread_count($task) );
 
   $fm->run_on_finish(
     sub {
