@@ -9,7 +9,7 @@ package Rex::Virtualization::LibVirt::import;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.1'; # VERSION
+our $VERSION = '1.3.0'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -34,8 +34,9 @@ sub execute {
   my $cwd = i_run "pwd";
   chomp $cwd;
 
-  my $dir  = dirname $opt{file};
-  my $file = "storage/" . basename $opt{file};
+  my $dir = dirname $opt{file};
+  my ( undef, undef, $suffix ) = fileparse( $opt{file}, qr{\.[^.]*} );
+  my $file = "storage/" . $dom . $suffix;
   mkdir "./storage";
 
   my $format = "qcow2";
